@@ -16,7 +16,7 @@ from datetime import datetime
 
 logger = logging.getLogger(__name__)
 
-_RESPONSE_TIMEOUT = 2.0
+_RESPONSE_TIMEOUT = 5
 
 
 class HomeduinoProtocol(asyncio.Protocol):
